summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDoug Kearns <dougkearns@gmail.com>2009-09-25 16:00:48 +1000
committerDoug Kearns <dougkearns@gmail.com>2009-09-25 16:00:48 +1000
commit1dde7029dfc619d325d43a6311693e1f6a0b4e08 (patch)
treec9bcdba9b6765769bcf0d89f9d94fb9c21d536a0
parent4daa9ace532322a0935732572a840ca034f8506d (diff)
downloadpentadactyl-1dde7029dfc619d325d43a6311693e1f6a0b4e08.tar.gz
Add XTML2 support to the Buffer#evaluateXPath namespace resolver.
--HG-- extra : transplant_source : 2v%E9%27%09%0B%23%09%86%96%96h%40v%9B%3D%24%F2%AD%17
-rw-r--r--common/content/buffer.js5
1 files changed, 3 insertions, 2 deletions
diff --git a/common/content/buffer.js b/common/content/buffer.js
index f16fcb57..7a66a5f7 100644
--- a/common/content/buffer.js
+++ b/common/content/buffer.js
@@ -1004,8 +1004,8 @@ function Buffer() //{{{
/**
* Evaluates an XPath expression in the current or provided
* document. It provides the xhtml and liberator XML namespaces. The
* result may be used as an iterator.
*
* @param {string} expression The XPath expression to evaluate.
* @param {Document} doc The document to evaluate the expression in.
@@ -1027,6 +1027,7 @@ function Buffer() //{{{
{
return {
xhtml: "http://www.w3.org/1999/xhtml",
+ xhtml2: "http://www.w3.org/2002/06/xhtml2",
liberator: NS.uri
}[prefix] || null;
},
@@ -1004,8 +1004,8 @@ function Buffer() //{{{
/**
* Evaluates an XPath expression in the current or provided
- * document. It provides the xhtml and liberator XML namespaces. The
- * result may be used as an iterator.
+ * document. It provides the xhtml, xhtml2 and liberator XML
+ * namespaces. The result may be used as an iterator.
*
* @param {string} expression The XPath expression to evaluate.